@@ -23,14 +23,14 @@ else:
 __all__ = (
     "BatchGetRecordErrorTypeDef",
     "BatchGetRecordIdentifierTypeDef",
-    "BatchGetRecordRequestTypeDef",
-    "BatchGetRecordResponseResponseTypeDef",
+    "BatchGetRecordRequestRequestTypeDef",
+    "BatchGetRecordResponseTypeDef",
     "BatchGetRecordResultDetailTypeDef",
-    "DeleteRecordRequestTypeDef",
+    "DeleteRecordRequestRequestTypeDef",
     "FeatureValueTypeDef",
-    "GetRecordRequestTypeDef",
-    "GetRecordResponseResponseTypeDef",
-    "PutRecordRequestTypeDef",
+    "GetRecordRequestRequestTypeDef",
+    "GetRecordResponseTypeDef",
+    "PutRecordRequestRequestTypeDef",
     "ResponseMetadataTypeDef",
 )
 
@@ -66,15 +66,15 @@ class BatchGetRecordIdentifierTypeDef(
     pass
 
 
-BatchGetRecordRequestTypeDef = TypedDict(
-    "BatchGetRecordRequestTypeDef",
+BatchGetRecordRequestRequestTypeDef = TypedDict(
+    "BatchGetRecordRequestRequestTypeDef",
     {
         "Identifiers": List["BatchGetRecordIdentifierTypeDef"],
     },
 )
 
-BatchGetRecordResponseResponseTypeDef = TypedDict(
-    "BatchGetRecordResponseResponseTypeDef",
+BatchGetRecordResponseTypeDef = TypedDict(
+    "BatchGetRecordResponseTypeDef",
     {
         "Records": List["BatchGetRecordResultDetailTypeDef"],
         "Errors": List["BatchGetRecordErrorTypeDef"],
@@ -92,8 +92,8 @@ BatchGetRecordResultDetailTypeDef = TypedDict(
     },
 )
 
-DeleteRecordRequestTypeDef = TypedDict(
-    "DeleteRecordRequestTypeDef",
+DeleteRecordRequestRequestTypeDef = TypedDict(
+    "DeleteRecordRequestRequestTypeDef",
     {
         "FeatureGroupName": str,
         "RecordIdentifierValueAsString": str,
@@ -109,15 +109,15 @@ FeatureValueTypeDef = TypedDict(
     },
 )
 
-_RequiredGetRecordRequestTypeDef = TypedDict(
-    "_RequiredGetRecordRequestTypeDef",
+_RequiredGetRecordRequestRequestTypeDef = TypedDict(
+    "_RequiredGetRecordRequestRequestTypeDef",
     {
         "FeatureGroupName": str,
         "RecordIdentifierValueAsString": str,
     },
 )
-_OptionalGetRecordRequestTypeDef = TypedDict(
-    "_OptionalGetRecordRequestTypeDef",
+_OptionalGetRecordRequestRequestTypeDef = TypedDict(
+    "_OptionalGetRecordRequestRequestTypeDef",
     {
         "FeatureNames": List[str],
     },
@@ -125,20 +125,22 @@ _OptionalGetRecordRequestTypeDef = TypedDict(
 )
 
 
-class GetRecordRequestTypeDef(_RequiredGetRecordRequestTypeDef, _OptionalGetRecordRequestTypeDef):
+class GetRecordRequestRequestTypeDef(
+    _RequiredGetRecordRequestRequestTypeDef, _OptionalGetRecordRequestRequestTypeDef
+):
     pass
 
 
-GetRecordResponseResponseTypeDef = TypedDict(
-    "GetRecordResponseResponseTypeDef",
+GetRecordResponseTypeDef = TypedDict(
+    "GetRecordResponseTypeDef",
     {
         "Record": List["FeatureValueTypeDef"],
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-PutRecordRequestTypeDef = TypedDict(
-    "PutRecordRequestTypeDef",
+PutRecordRequestRequestTypeDef = TypedDict(
+    "PutRecordRequestRequestTypeDef",
     {
         "FeatureGroupName": str,
         "Record": List["FeatureValueTypeDef"],
